@@ -10,9 +10,7 @@ use Path::Class 'file';
 use File::Path 'make_path';
 use Pod::Usage;
 
-extends 'App::SimulateReads::CLI::Command';
-
-our $VERSION = '0.1.0'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 use constant {
 	COUNT_LOOPS_BY_OPT    => ['coverage', 'number-of-reads'],
@@ -21,8 +19,9 @@ use constant {
 	SEQUENCING_TYPE_OPT   => ['single-end', 'paired-end']
 };
 
-override 'opt_spec' => sub {
-	super,
+sub opt_spec {
+	'help|h',
+	'man|M',
 	'prefix|p=s',
 	'verbose|v',
 	'output-dir|o=s',
@@ -39,7 +38,7 @@ override 'opt_spec' => sub {
 	'seqid-weight|w=s',
 	'number-of-reads|n=i',
 	'weight-file|f=s'
-};
+}
 
 sub _default_opt {
 	'verbose'          => 0,
@@ -59,6 +58,15 @@ sub _default_opt {
 	'quality-profile'  => 'hiseq'
 }
 
+sub _fill_opts {
+	my ($self, $opts) = @_;
+	my %default_opt = $self->_default_opt;
+
+	for my $opt (keys %default_opt) {
+		$opts->{$opt} = $default_opt{$opt} if not exists $opts->{$opt};
+	}
+}
+
 sub _log_msg_opt {
 	my ($self, $opts) = @_;
 	while (my ($key, $value) = each %$opts) {
@@ -98,8 +106,7 @@ sub validate_args {
 
 sub validate_opts {
 	my ($self, $opts) = @_;
-	my %default_opt = $self->_default_opt;
-	$self->fill_opts($opts, \%default_opt);
+	$self->_fill_opts($opts);
 
 	# Possible alternatives
 	my %STRAND_BIAS       = map { $_ => 1 } @{ &STRAND_BIAS_OPT     };
@@ -215,9 +222,7 @@ sub validate_opts {
 sub execute {
 	my ($self, $opts, $args) = @_;
 	my $fasta_file = shift @$args;
-
-	my %default_opt = $self->_default_opt;
-	$self->fill_opts($opts, \%default_opt);
+	$self->_fill_opts($opts);
 
 	# Set if user wants a verbose log
 	$LOG_VERBOSE = $opts->{verbose};
@@ -244,15 +249,13 @@ sub execute {
 	#  Log presentation header
 	#-------------------------------------------------------------------------------
 	my $time_stamp = localtime;
-	my $progname   = $self->progname;
-	my $argv = $self->argv;
+	my $progname   = file($0)->basename;
 log_msg <<"HEADER";
---------------------------------------------------------
+-------------------------------------------------------------
  Date $time_stamp
+ Teaching and Research Institute from Sírio-Libanês Hospital
  $progname Copyright (C) 2017 Thiago L. A. Miller
---------------------------------------------------------
-:: Arguments passed by the user:
-  => '@$argv'
+-------------------------------------------------------------
 HEADER
 
 	#-------------------------------------------------------------------------------
@@ -323,7 +326,7 @@ App::SimulateReads::Command::Digest - digest command class. Simulate single-end
 
 =head1 VERSION
 
-version 0.1.0
+version 0.01
 
 =head1 SYNOPSIS
 
