@@ -4,9 +4,7 @@ package App::SimulateReads::Command::QualityDB;
 use App::SimulateReads::Base 'class';
 use App::SimulateReads::Quality::Handle;
 
-extends 'App::SimulateReads::CLI::Command';
-
-our $VERSION = '0.1.0'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 has 'db' => (
 	is         => 'ro',
@@ -20,9 +18,10 @@ sub _build_db {
 	return App::SimulateReads::Quality::Handle->new;
 }
 
-override 'opt_spec' => sub {
-	super
-};
+sub opt_spec {
+	'help|h',
+	'man|M'
+}
 
 sub subcommand_map {
 	add     => 'App::SimulateReads::Command::QualityDB::Add',
@@ -69,7 +68,7 @@ App::SimulateReads::Command::QualityDB - qualitydb command class. Manage quality
 
 =head1 VERSION
 
-version 0.1.0
+version 0.01
 
 =head1 SYNOPSIS
 
