@@ -5,14 +5,15 @@ use App::SimulateReads::Base 'class';
 
 extends 'App::SimulateReads::Command::QualityDB';
 
-our $VERSION = '0.1.0'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
-override 'opt_spec' => sub {
-	super,
+sub opt_spec {
+	'help|h',
+	'man|M',
 	'verbose|v',
 	'quality-profile|q=s',
 	'read-size|r=i'
-};
+}
 
 sub validate_args {
 	my ($self, $args) = @_;
@@ -51,7 +52,7 @@ App::SimulateReads::Command::QualityDB::Remove - qualitydb subcommand class. Rem
 
 =head1 VERSION
 
-version 0.1.0
+version 0.01
 
 =head1 SYNOPSIS
 
