@@ -5,12 +5,13 @@ use App::SimulateReads::Base 'class';
 
 extends 'App::SimulateReads::Command::QualityDB';
 
-our $VERSION = '0.1.0'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
-override 'opt_spec' => sub {
-	super,
+sub opt_spec {
+	'help|h',
+	'man|M',
 	'verbose|v'
-};
+}
 
 sub validate_args {
 	my ($self, $args) = @_;
@@ -39,7 +40,7 @@ App::SimulateReads::Command::QualityDB::Restore - qualitydb subcommand class. Re
 
 =head1 VERSION
 
-version 0.1.0
+version 0.01
 
 =head1 SYNOPSIS
 
